@@ -1,10 +1,16 @@
-#ifndef _LIB_R_FS_H_
-#define _LIB_R_FS_H_
+#ifndef R2_FS_H
+#define R2_FS_H
 
 #include <r_types.h>
 #include <r_list.h>
 #include <r_io.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+R_LIB_VERSION_HEADER (r_fs);
+
 struct r_fs_plugin_t;
 struct r_fs_root_t;
 struct r_fs_t;
@@ -17,6 +23,10 @@ typedef struct r_fs_t {
 	void *ptr;
 } RFS;
 
+typedef struct r_fs_partition_plugin_t {
+	const char *name;
+} RFSPartitionPlugin;
+
 typedef struct r_fs_file_t {
 	char *name;
 	char *path;
@@ -44,11 +54,11 @@ typedef struct r_fs_plugin_t {
 	const char *desc;
 	RFSFile* (*slurp)(RFSRoot *root, const char *path);
 	RFSFile* (*open)(RFSRoot *root, const char *path);
-	boolt (*read)(RFSFile *fs, ut64 addr, int len);
+	bool (*read)(RFSFile *fs, ut64 addr, int len);
 	void (*close)(RFSFile *fs);
 	RList *(*dir)(RFSRoot *root, const char *path, int view);
-	void (*init)();
-	void (*fini)();
+	void (*init)(void);
+	void (*fini)(void);
 	int (*mount)(RFSRoot *root);
 	void (*umount)(RFSRoot *root);
 } RFSPlugin;
@@ -67,9 +77,12 @@ typedef struct r_fs_partition_t {
 #define R_FS_FILE_TYPE_SPECIAL 's'
 #define R_FS_FILE_TYPE_MOUNT 'm'
 
+typedef int (*RFSPartitionIterator)(void *disk, void *ptr, void *user);
 typedef struct r_fs_partition_type_t {
 	const char *name;
-	void *ptr;
+	void *ptr; // grub_msdos_partition_map
+	RFSPartitionIterator iterate;
+	//RFSPartitionIterator parhook;
 } RFSPartitionType;
 #define R_FS_PARTITIONS_LENGTH (int)(sizeof (partitions)/sizeof(RFSPartitionType)-1)
 
@@ -81,35 +94,36 @@ enum {
 };
 
 #ifdef R_API
-R_API RFS *r_fs_new ();
-R_API void r_fs_view (RFS* fs, int view);
-R_API void r_fs_free (RFS* fs);
-R_API void r_fs_add (RFS *fs, RFSPlugin *p);
-R_API void r_fs_del (RFS *fs, RFSPlugin *p);
-R_API RFSRoot *r_fs_mount (RFS* fs, const char *fstype, const char *path, ut64 delta);
-R_API boolt r_fs_umount (RFS* fs, const char *path);
-R_API RList *r_fs_root (RFS *fs, const char *path);
-R_API RFSFile *r_fs_open (RFS* fs, const char *path);
-R_API void r_fs_close (RFS* fs, RFSFile *file);
-R_API int r_fs_read (RFS* fs, RFSFile *file, ut64 addr, int len);
+R_API RFS *r_fs_new(void);
+R_API void r_fs_view(RFS* fs, int view);
+R_API void r_fs_free(RFS* fs);
+R_API void r_fs_add(RFS *fs, RFSPlugin *p);
+R_API void r_fs_del(RFS *fs, RFSPlugin *p);
+R_API RFSRoot *r_fs_mount(RFS* fs, const char *fstype, const char *path, ut64 delta);
+R_API bool r_fs_umount(RFS* fs, const char *path);
+R_API RList *r_fs_root(RFS *fs, const char *path);
+R_API RFSFile *r_fs_open(RFS* fs, const char *path);
+R_API void r_fs_close(RFS* fs, RFSFile *file);
+R_API int r_fs_read(RFS* fs, RFSFile *file, ut64 addr, int len);
 R_API RFSFile *r_fs_slurp(RFS* fs, const char *path);
 R_API RList *r_fs_dir(RFS* fs, const char *path);
-R_API int r_fs_dir_dump (RFS* fs, const char *path, const char *name);
-R_API RList *r_fs_find_name (RFS* fs, const char *name, const char *glob);
-R_API RList *r_fs_find_off (RFS* fs, const char *name, ut64 off);
+R_API int r_fs_dir_dump(RFS* fs, const char *path, const char *name);
+R_API RList *r_fs_find_name(RFS* fs, const char *name, const char *glob);
+R_API RList *r_fs_find_off(RFS* fs, const char *name, ut64 off);
 R_API RList *r_fs_partitions(RFS* fs, const char *ptype, ut64 delta);
-R_API int r_fs_prompt (RFS *fs, const char *root);
+R_API char *r_fs_name(RFS *fs, ut64 offset);
+R_API int r_fs_prompt(RFS *fs, const char *root);
 
 /* file.c */
-R_API RFSFile *r_fs_file_new (RFSRoot *root, const char *path);
-R_API void r_fs_file_free (RFSFile *file);
-R_API RFSRoot *r_fs_root_new (const char *path, ut64 delta);
-R_API void r_fs_root_free (RFSRoot *root);
+R_API RFSFile *r_fs_file_new(RFSRoot *root, const char *path);
+R_API void r_fs_file_free(RFSFile *file);
+R_API RFSRoot *r_fs_root_new(const char *path, ut64 delta);
+R_API void r_fs_root_free(RFSRoot *root);
 R_API RFSPartition *r_fs_partition_new(int num, ut64 start, ut64 length);
-R_API void r_fs_partition_free (RFSPartition *p);
-R_API const char *r_fs_partition_type (const char *part, int type);
-R_API const char *r_fs_partition_type_get (int n);
-R_API int r_fs_partition_get_size (); // WTF. wrong function name
+R_API void r_fs_partition_free(RFSPartition *p);
+R_API const char *r_fs_partition_type(const char *part, int type);
+R_API const char *r_fs_partition_type_get(int n);
+R_API int r_fs_partition_get_size(void); // WTF. wrong function name
 
 /* plugins */
 extern RFSPlugin r_fs_plugin_ext2;
@@ -134,5 +148,11 @@ extern RFSPlugin r_fs_plugin_xfs;
 extern RFSPlugin r_fs_plugin_fb;
 extern RFSPlugin r_fs_plugin_minix;
 extern RFSPlugin r_fs_plugin_posix;
+extern RFSPlugin r_fs_plugin_squash;
 #endif
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif
